#
# spec file for package libcacard
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libcacard
URL:            https://gitlab.freedesktop.org/spice/libcacard
Summary:        Common Access Card (CAC) emulation
License:        LGPL-2.1-or-later
Group:          System/Emulators/PC
Version:        2.8.1
Release:        1.11
Source:         http://www.spice-space.org/download/libcacard/%{name}-%{version}.tar.xz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gcc-c++
BuildRequires:  glib2-devel >= 2.32
BuildRequires:  meson
BuildRequires:  mozilla-nss-devel
BuildRequires:  pkg-config

%description
This emulator is designed to provide emulation of actual smart cards to a
virtual card reader running in a guest virtual machine. The emulated smart
cards can be representations of real smart cards, where the necessary functions
such as signing, card removal/insertion, etc. are mapped to real, physical
cards which are shared with the client machine the emulator is running on, or
the cards could be pure software constructs.

%package -n libcacard0
Summary:        Common Access Card (CAC) emulation
Group:          System/Emulators/PC

%description -n libcacard0
This emulator is designed to provide emulation of actual smart cards to a
virtual card reader running in a guest virtual machine. The emulated smart
cards can be representations of real smart cards, where the necessary functions
such as signing, card removal/insertion, etc. are mapped to real, physical
cards which are shared with the client machine the emulator is running on, or
the cards could be pure software constructs.

%package devel
Summary:        Common Access Card (CAC) emulation -- Development files
Group:          Development/Languages/C and C++
Requires:       glib2-devel
Requires:       libcacard0 = %version
Requires:       mozilla-nspr
Requires:       mozilla-nss

%description devel
This emulator is designed to provide emulation of actual smart cards to a
virtual card reader running in a guest virtual machine. The emulated smart
cards can be representations of real smart cards, where the necessary functions
such as signing, card removal/insertion, etc. are mapped to real, physical
cards which are shared with the client machine the emulator is running on, or
the cards could be pure software constructs.

This sub-package contains development files for the Smartcard library.

%prep
%setup -q

%build
%meson -Dpcsc=disabled -Ddisable_tests=true
%meson_build

%install
%meson_install
rm -f %{buildroot}%{_libdir}/libcacard.a
rm -f %{buildroot}%{_libdir}/libcacard.la

%post   -n libcacard0 -p /sbin/ldconfig

%postun -n libcacard0 -p /sbin/ldconfig

%files -n libcacard0
%defattr(-, root, root)
%{_libdir}/libcacard.so.0*

%files devel
%defattr(-, root, root)
%dir %{_includedir}/cacard
%{_includedir}/cacard/*.h
%{_libdir}/libcacard.so
%{_libdir}/pkgconfig/libcacard.pc

%changelog
* Thu Dec  9 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.8.1
  * Unbreak RAW deciphering emulation using RSA-PKCS1 method
  * Use g_memdup2 to avoid deprecation warnings with new glib2
* Tue Dec  1 2020 Bruce Rogers <brogers@suse.com>
- Update to v2.8.0. Changes include:
  * Improve project documentation
  * Bump minimal glib version to 2.32 and remove old compatibility functions
  * Introduce meson build system in addition to existing autotools
  * Create and run fuzzer drivers to improve stability
  * Introduce a new API vcard_emul_finalize() to clean up allocated resources
  * Remove key caching to avoid issues with some PKCS #11 modules
  * Prevent logging critical errors on unknown instruction
- Remove empty libcacard package, and also drop the rpm provided
  symbol qemu-tools:/usr/bin/vscclient, both assumed unused by now
* Tue Nov 26 2019 Bruce Rogers <brogers@suse.com>
- Update to v2.7.0. Changes include:
  * Improve compatibility with Windows guests, particularly with
  ActivClient Windows drivers.
  * Implement Microsoft PnP applet used by Windows for card detection
  * Fill several structures returned by Global Platform applet to
  mimic behavior of real cards.
  * Implement API for creation of serial number used to uniquely
  identify a emulated card.
  * More verbose debug logs
  * Fix the VERIFY semantics, which can be used for login status
  check
  * Add clang and csbuild CI targets
  * Use ATR from official CAC card to improve card detection under
  Windows
* Fri May 17 2019 Bruce Rogers <brogers@suse.com>
- Update to v2.6.1
  * various bug fixes (memory corruption issues which would cause
  crashes in spice-gtk)
* Wed Aug 15 2018 brogers@suse.com
- Update to v2.6.0
  * provides implementation of GSC-IS 2.1 (aka CAC version 2) to improve
  interoperability with guest software using the emulated or shared
  smart cards. The previously implemented CACv1 specification is no
  longer supported by any other application so the old code is gone
  and any application depending on this old standard will not work
  anymore.
  * vscclient is no longer installed, as it is not an end-user supported
  solution
  * various bug & leak fixes
* Wed May  3 2017 brogers@suse.com
- Update to v2.5.3
  * Includes fix for host memory leakage while creating new APDU
  (CVE-2017-6414 boo#1027514)
* Tue Jan 19 2016 afaerber@suse.de
- Initial - split out from QEMU
